@@ -1,15 +1,16 @@
 ar.bugs <-
-function(y, ar.order=1, h=NULL, sim=FALSE, 
-                  mean.centre=FALSE, st=ar.order+1,
-                  mean.prior=ar.prior, ar.prior="dnorm(0,1)", tol.prior="dgamma(0.000001,0.000001)", var.prior=NULL, sd.prior=NULL){
+function(y, ar.order=1, k=NULL, sim=FALSE, 
+                  mean.centre=FALSE, beg=ar.order+1,
+                  mean.prior=ar.prior, ar.prior="dnorm(0,1)", tol.prior="dgamma(0.000001,0.000001)", var.prior=NULL, sd.prior=NULL,
+                  space=FALSE){
   y<-c(y)
   n<-length(y)
-  if(!is.null(h)){
-    y<-c(y,rep(NA,h))
+  if(!is.null(k)){
+    y<-c(y,rep(NA,k))
   }
-  h<-length(y)-max(which(!is.na(y)))
-  if(st<ar.order)
-    stop("The value of st must be at least 1 greater than the number of lags")
+  k<-length(y)-max(which(!is.na(y)))
+  if(beg<ar.order)
+    stop("The value of beg must be at least 1 greater than the number of lags")
   if(!is.null(var.prior) | !is.null(sd.prior)){
     tol.prior<-NULL
   }
@@ -19,15 +20,15 @@ function(y, ar.order=1, h=NULL, sim=FALSE,
   bug<-c("model{","")
   #likelihood
   lik<-c("#likelihood",
-         paste0("for(t in ",st,":",n+h,"){"),
+         paste0("for(t in ",beg,":",n+k,"){"),
          "\ty[t] ~ dnorm(y.mean[t], isigma2)",
          "}")
   bug<-c(bug, lik)
   #ymean
   ymean<-c("#mean",
-           paste0("for(t in ",st,":",n+h,"){"),
+           paste0("for(t in ",beg,":",n+k,"){"),
            y.mean<-c("\ty.mean[t] <- 0",
-           "}")
+                     "}")
   )
   if(ar.order==0 & mean.centre==T)  ymean[3]<-"\ty.mean[t] <- phi0"
   if(ar.order!=0 & mean.centre==F)  ymean[3]<-paste0("\ty.mean[t] <- ",paste0("phi",1:ar.order,"*y[t-",1:ar.order,"]",collapse=" + "))
@@ -53,12 +54,12 @@ function(y, ar.order=1, h=NULL, sim=FALSE,
   ar.priors<-ar.priors[-1]
   if(mean.centre==T)  ar.priors<-c(paste0("phi0 ~ ",mean.prior),ar.priors)
   bug<-c(bug,"#priors",ar.priors,"")
-    
+  
   #forecast
   forc<-NULL
-  if(h!=0){
-    forc<-c("#forecasts",
-            paste("for(t in ",n+1,":",n+h,"){",sep=""),
+  if(k!=0){
+    forc<-c("#forecast",
+            paste("for(t in ",n+1,":",n+k,"){",sep=""),
             "\ty.new[t] <- y[t]",
             "}",
             "")
@@ -68,9 +69,9 @@ function(y, ar.order=1, h=NULL, sim=FALSE,
   #simulation
   ysim<-NULL
   if(sim==TRUE){
-    ysim<-c("#simulations",
+    ysim<-c("#simulation",
             "isigma2.c <- cut(isigma2)",
-            paste("for(t in ",st,":",n,"){",sep=""),
+            paste("for(t in ",beg,":",n,"){",sep=""),
             "\ty.mean.c[t] <- cut(y.mean[t])",
             "\ty.sim[t] ~ dnorm(y.mean.c[t],isigma2.c)",
             "}",
@@ -80,33 +81,39 @@ function(y, ar.order=1, h=NULL, sim=FALSE,
   bug<-c(bug,"}","")
   #print.tsbugs(list(bug=bug))
   
-  p1<-grep("likelihood",bug)
-  p2<-grep("prior",bug)
-  if(h!=0 & sim==TRUE){
-    p3<-grep("forecast",bug); p4<-grep("simulation",bug)
+  if(space==FALSE){
+    bug<-bug[-nchar(bug)!=0]
+    if(length(grep("#mean", bug))>0)
+      bug<-bug[-grep("#mean", bug)]
   }
-  if(h!=0 & sim==FALSE){
-    p3<-grep("forecast",bug); p4<-length(bug)
+    
+  p1<-grep("#likelihood",bug)
+  p2<-grep("#priors",bug)
+  if(k!=0 & sim==TRUE){
+    p3<-grep("#forecast",bug); p4<-grep("#simulation",bug)
   }
-  if(h==0 & sim==TRUE){
-    p3<-grep("simulation",bug); p4<-p3
+  if(k!=0 & sim==FALSE){
+    p3<-grep("#forecast",bug); p4<-length(bug)
+  }
+  if(k==0 & sim==TRUE){
+    p3<-grep("#simulation",bug); p4<-p3
   } 
-  if(h==0 & sim==FALSE){
+  if(k==0 & sim==FALSE){
     p3<-length(bug); p4<-p3
   } 
   p5<-length(bug)
   
   bug<-list(bug=bug,
             data=list(y=y),
-            info=list(n=n,h=h,nh=n+h,st=st,
+            info=list(n=n,k=k,nh=n+k,beg=beg,
                       args=mget(names(formals()),sys.frame(sys.nframe()))[-1],
                       variance="CV",
                       likelihood=p1:(p2-1),
                       priors=p2:(p3-1),
-                      forecasts=NULL,
-                      simulations=NULL))
-  if(p3!=p4)  bug$info$forecasts<-p3:(p4-1)
-  if(p4!=p5)  bug$info$simulations<-p4:(p5-1)
+                      forecast=NULL,
+                      simulation=NULL))
+  if(p3!=p4)  bug$info$forecast<-p3:(p4-1)
+  if(p4!=p5)  bug$info$simulation<-p4:(p5-1)
   class(bug)<-"tsbugs"
   return(bug)
 }
